@@ -23,8 +23,10 @@ const our $DEF_PAGE_SIZE => 250;
 
 const our $BUILD_STATUS_TEXT => {
     -4 => 'cancelled',
+    -2 => 'error',
     -1 => 'error',
     0  => 'queued',
+    1  => 'queued',
     3  => 'building',
     10 => 'success',
 };
@@ -613,12 +615,12 @@ sub trigger_autobuild_by_tag_name ( $self, $repo_id, $autobuild_tag_name, $cb =
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 77, 186, 320, 330,   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
-## |      | 346, 374, 378, 413,  |                                                                                                                |
-## |      | 485, 504, 508, 552,  |                                                                                                                |
-## |      | 565                  |                                                                                                                |
+## |    3 | 79, 188, 322, 332,   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |      | 348, 376, 380, 415,  |                                                                                                                |
+## |      | 487, 506, 510, 554,  |                                                                                                                |
+## |      | 567                  |                                                                                                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 164                  | CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    |
+## |    1 | 166                  | CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
